/*
  Name:        	TraceDesignFull.c
  Author:      	Ron Burkey
  Purpose:     	The processing for Do178Builder-utility 
  		that creates the traceability matrix for the
		--trace-design-full command-line switch.
  Mod History:	03/16/2008 RSB	Adapted from TraceDesign.c.
  
  Copyright 2008 Ronald S. Burkey

  This file is part of Do178Builder.

  Do178Builder is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Do178Builder is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Do178Builder; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  
  
  The dataset output by this function is a CSV file with one record 
  for each pairing of a high-level requirement with a low-level 
  requirement, along with the document sections (in the requirements
  and design documents) in which those requirements appear.  A requirement 
  which has no association is matched with "(none)".  For example, suppose 
  that high-level requirement H1 is associated with low-level requirements 
  L1 and L2, low-level requirement L3 is matched with high-level 
  requirements H2 and H3 (this shouldn't be possible!), H4 is matched with 
  L4, H5 is matched with nothing, and L5 is matched with nothing.  (The 
  actual names of the requirements are determined by user-supplied 
  information and are unlike to be something as simple as H5 or L5.  For 
  example, the high-level requirements might be things like EASDD.1234, 
  and the low-level requirements might be things like [SL5432].  I merely 
  use things like H5 and L5 because they're simple to write.)  Other 
  interesting information could include that sections of the requirements
  or design documents contain no requirements.  Then the output file would
  look like the following, though not necessarily with the records in the s
  ame order (with the first line containing column headers):
  
  	"High-Level Requirement","Requirements Document Section","Low-Level Requirement","Design Document Section"
  	"SRD H1","SRD 1.2.3.4","SDD L1","SDD 1.2.3.4.1.1"
	"SRD H1","SRD 1.2.3.4","(none)","SDD 1.2.3.4.1.2"
	"SRD H1","SRD 1.2.3.4","SDD L2","SDD 1.2.3.4.1.3"
	"(none)","SRD 1.2.3.5","(none)","SDD 1.2.3.5.1.1"
	"(none)","SRD 1.2.3.5","(none)","SDD 1.2.3.5.1.2"
	"SRD H2","SRD 1.2.3.6","SDD L3","SDD 1.2.3.6.1.1"
	"SRD H3","SRD 1.2.3.7","SDD L3","SDD 1.2.3.7.1.1"
	"SRD H4","SRD 1.2.3.7","SDD L4","SDD 1.2.3.7.1.1"
	"SRD H5","SRD 1.2.3.8","(none)","(none)"
	"(none)","SRD 1.2.3.9","SDD L5","SDD 1.2.3.9.1.1"

  For example, from the 5th and 6th lines of this table, you could 
  determine at a glance that while section 1.2.3.5 of the SRD is a
  place where we might expect to find high-level requirements, 
  in fact it doesn't contain any, and its related sections in the 
  SDD where we might expect to find some low-level requirements
  (1.2.3.5.1.1 and 1.2.3.5.1.2) also contain none.
  
  You might think that the notations "SRD" and "SDD" above are pointless
  (e.g., why "SRD H1" rather than just "H1"?), but reason they are 
  there is to allow easy combination of CSV data created from 
  different databases into a single table.  For example, one could 
  combine data from a DO-178B database and a DO-254 database, and
  the face that some items read "SRD H1" while others read "HRD H1"
  would allow the requirements from the different databases to 
  remain distinct.

  The requirements are identified by pattern matching with user-
  supplied regular expressions.  The associations occur whenever
  the low-level requirement appears either within the same node
  (document section) as the high-level requirement, or in any 
  child node (document sub-section) of that node.
  
  By sucking the CSV file into a spreadsheet program, it can be sorted 
  in order of the high-level requirements or in order of the low-level
  requirements.  The actual output order is simply the order in which
  the requirements are found in the XML.
*/


///////////////////////////////////////////////////////////////////////
//                  *****  IMPORTANT NOTE!  *****

// We can get most of the functionality we want for TraceDesign.c simply
// by reusing TraceDesign.c, and then replacing a lot of items like 
// TraceDesignState by items like TraceDesignFullState.  I suppose this
// might be confusing in some ways, but it makes for a lot more 
// error-free conversion than cutting-and-pasting everything and 
// renaming a bunch of objects, I hope ... or at least, initially it's
// more error-free.  

// This constant activates extra features within TraceDesign.c that are 
// specific to --trace-design-full as opposed to --trace-design.
#define TRACE_DESIGN_FULL

//               *****  END OF IMPORTANT NOTE!  *****
///////////////////////////////////////////////////////////////////////

#include "TraceDesign.c"

